ZSTD_cParameter class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- ZSTD_c_chainLog → const int
- ZSTD_c_checksumFlag → const int
- ZSTD_c_compressionLevel → const int
- ZSTD_c_contentSizeFlag → const int
- ZSTD_c_dictIDFlag → const int
- ZSTD_c_enableLongDistanceMatching → const int
- ZSTD_c_experimentalParam1 → const int
- ZSTD_c_experimentalParam2 → const int
- ZSTD_c_experimentalParam3 → const int
- ZSTD_c_experimentalParam4 → const int
- ZSTD_c_experimentalParam5 → const int
- ZSTD_c_experimentalParam6 → const int
- ZSTD_c_experimentalParam7 → const int
- ZSTD_c_experimentalParam8 → const int
- ZSTD_c_experimentalParam9 → const int
- ZSTD_c_experimentalParam10 → const int
- ZSTD_c_hashLog → const int
- ZSTD_c_jobSize → const int
- ZSTD_c_ldmBucketSizeLog → const int
- ZSTD_c_ldmHashLog → const int
- ZSTD_c_ldmHashRateLog → const int
- ZSTD_c_ldmMinMatch → const int
- ZSTD_c_minMatch → const int
- ZSTD_c_nbWorkers → const int
- ZSTD_c_overlapLog → const int
- ZSTD_c_searchLog → const int
- ZSTD_c_strategy → const int
- ZSTD_c_targetLength → const int
- ZSTD_c_windowLog → const int