ZStd class
zstd ffi binding in Dart
Constructors
- ZStd(DynamicLibrary dynamicLibrary)
-
The symbols are looked up in
dynamicLibrary. -
ZStd.fromLookup(Pointer<
T> lookup<T extends NativeType>(String symbolName) ) -
The symbols are looked up with
lookup.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
ZSTD_CCtx_loadDictionary(
Pointer< ZSTD_CCtx> cctx, Pointer<Void> dict, int dictSize) → int -
ZSTD_CCtx_refCDict(
Pointer< ZSTD_CCtx> cctx, Pointer<ZSTD_CDict> cdict) → int -
ZSTD_CCtx_refPrefix(
Pointer< ZSTD_CCtx> cctx, Pointer<Void> prefix, int prefixSize) → int -
ZSTD_CCtx_reset(
Pointer< ZSTD_CCtx> cctx, int reset) → int -
ZSTD_CCtx_setParameter(
Pointer< ZSTD_CCtx> cctx, int param, int value) → int -
ZSTD_CCtx_setPledgedSrcSize(
Pointer< ZSTD_CCtx> cctx, int pledgedSrcSize) → int -
ZSTD_compress(
Pointer< Void> dst, int dstCapacity, Pointer<Void> src, int srcSize, int compressionLevel) → int -
ZSTD_compress2(
Pointer< ZSTD_CCtx> cctx, Pointer<Void> dst, int dstCapacity, Pointer<Void> src, int srcSize) → int -
ZSTD_compress_usingCDict(
Pointer< ZSTD_CCtx> cctx, Pointer<Void> dst, int dstCapacity, Pointer<Void> src, int srcSize, Pointer<ZSTD_CDict> cdict) → int -
ZSTD_compress_usingDict(
Pointer< ZSTD_CCtx> ctx, Pointer<Void> dst, int dstCapacity, Pointer<Void> src, int srcSize, Pointer<Void> dict, int dictSize, int compressionLevel) → int -
ZSTD_compressBound(
int srcSize) → int -
ZSTD_compressCCtx(
Pointer< ZSTD_CCtx> cctx, Pointer<Void> dst, int dstCapacity, Pointer<Void> src, int srcSize, int compressionLevel) → int -
ZSTD_compressStream(
Pointer< ZSTD_CStream> zcs, Pointer<ZSTD_outBuffer> output, Pointer<ZSTD_inBuffer> input) → int -
ZSTD_compressStream2(
Pointer< ZSTD_CCtx> cctx, Pointer<ZSTD_outBuffer> output, Pointer<ZSTD_inBuffer> input, int endOp) → int -
ZSTD_cParam_getBounds(
int cParam) → ZSTD_bounds -
ZSTD_createCCtx(
) → Pointer< ZSTD_CCtx> -
ZSTD_createCDict(
Pointer< Void> dictBuffer, int dictSize, int compressionLevel) → Pointer<ZSTD_CDict> -
ZSTD_createCStream(
) → Pointer< ZSTD_CStream> -
ZSTD_createDCtx(
) → Pointer< ZSTD_DCtx> -
ZSTD_createDDict(
Pointer< Void> dictBuffer, int dictSize) → Pointer<ZSTD_DDict> -
ZSTD_createDStream(
) → Pointer< ZSTD_DStream> -
ZSTD_CStreamInSize(
) → int -
ZSTD_CStreamOutSize(
) → int -
ZSTD_DCtx_loadDictionary(
Pointer< ZSTD_DCtx> dctx, Pointer<Void> dict, int dictSize) → int -
ZSTD_DCtx_refDDict(
Pointer< ZSTD_DCtx> dctx, Pointer<ZSTD_DDict> ddict) → int -
ZSTD_DCtx_refPrefix(
Pointer< ZSTD_DCtx> dctx, Pointer<Void> prefix, int prefixSize) → int -
ZSTD_DCtx_reset(
Pointer< ZSTD_DCtx> dctx, int reset) → int -
ZSTD_DCtx_setParameter(
Pointer< ZSTD_DCtx> dctx, int param, int value) → int -
ZSTD_decompress(
Pointer< Void> dst, int dstCapacity, Pointer<Void> src, int compressedSize) → int -
ZSTD_decompress_usingDDict(
Pointer< ZSTD_DCtx> dctx, Pointer<Void> dst, int dstCapacity, Pointer<Void> src, int srcSize, Pointer<ZSTD_DDict> ddict) → int -
ZSTD_decompress_usingDict(
Pointer< ZSTD_DCtx> dctx, Pointer<Void> dst, int dstCapacity, Pointer<Void> src, int srcSize, Pointer<Void> dict, int dictSize) → int -
ZSTD_decompressDCtx(
Pointer< ZSTD_DCtx> dctx, Pointer<Void> dst, int dstCapacity, Pointer<Void> src, int srcSize) → int -
ZSTD_decompressStream(
Pointer< ZSTD_DStream> zds, Pointer<ZSTD_outBuffer> output, Pointer<ZSTD_inBuffer> input) → int -
ZSTD_dParam_getBounds(
int dParam) → ZSTD_bounds -
ZSTD_DStreamInSize(
) → int -
ZSTD_DStreamOutSize(
) → int -
ZSTD_endStream(
Pointer< ZSTD_CStream> zcs, Pointer<ZSTD_outBuffer> output) → int -
ZSTD_findFrameCompressedSize(
Pointer< Void> src, int srcSize) → int -
ZSTD_flushStream(
Pointer< ZSTD_CStream> zcs, Pointer<ZSTD_outBuffer> output) → int -
ZSTD_freeCCtx(
Pointer< ZSTD_CCtx> cctx) → int -
ZSTD_freeCDict(
Pointer< ZSTD_CDict> CDict) → int -
ZSTD_freeCStream(
Pointer< ZSTD_CStream> zcs) → int -
ZSTD_freeDCtx(
Pointer< ZSTD_DCtx> dctx) → int -
ZSTD_freeDDict(
Pointer< ZSTD_DDict> ddict) → int -
ZSTD_freeDStream(
Pointer< ZSTD_DStream> zds) → int -
ZSTD_getDecompressedSize(
Pointer< Void> src, int srcSize) → int -
ZSTD_getDictID_fromDDict(
Pointer< ZSTD_DDict> ddict) → int -
ZSTD_getDictID_fromDict(
Pointer< Void> dict, int dictSize) → int -
ZSTD_getDictID_fromFrame(
Pointer< Void> src, int srcSize) → int -
ZSTD_getErrorName(
int code) → Pointer< Char> -
ZSTD_getFrameContentSize(
Pointer< Void> src, int srcSize) → int -
ZSTD_initCStream(
Pointer< ZSTD_CStream> zcs, int compressionLevel) → int -
ZSTD_initDStream(
Pointer< ZSTD_DStream> zds) → int -
ZSTD_isError(
int code) → int -
ZSTD_maxCLevel(
) → int -
ZSTD_minCLevel(
) → int -
ZSTD_sizeof_CCtx(
Pointer< ZSTD_CCtx> cctx) → int -
ZSTD_sizeof_CDict(
Pointer< ZSTD_CDict> cdict) → int -
ZSTD_sizeof_CStream(
Pointer< ZSTD_CStream> zcs) → int -
ZSTD_sizeof_DCtx(
Pointer< ZSTD_DCtx> dctx) → int -
ZSTD_sizeof_DDict(
Pointer< ZSTD_DDict> ddict) → int -
ZSTD_sizeof_DStream(
Pointer< ZSTD_DStream> zds) → int -
ZSTD_versionNumber(
) → int -
ZSTD_versionString(
) → Pointer< Char>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited